@@ -15,9 +15,7 @@ from . import malojatime
 from . import utilities
 from . import malojauri
 from .utilities import resolveImage
-from .urihandler import remove_identical
-from .malojauri import uri_to_internal
-from . import urihandler
+from .malojauri import uri_to_internal, remove_identical
 from . import globalconf
 from .jinjaenv.context import jinja_environment
 # doreah toolkit
@@ -35,6 +33,7 @@ import os
 import setproctitle
 import pkg_resources
 import math
+from htmlmin.decorator import htmlmin
 # url handling
 import urllib
 
@@ -192,8 +191,6 @@ aliases = {
 
 
 
-
-
 @webserver.route("/<name:re:admin.*>")
 @auth.authenticated
 def static_html_private(name):
@@ -203,6 +200,7 @@ def static_html_private(name):
 def static_html_public(name):
 	return static_html(name)
 
+@htmlmin
 def static_html(name):
 	if name in aliases: redirect(aliases[name])
 	linkheaders = ["</style.css>; rel=preload; as=style"]
