@@ -48,85 +48,6 @@ def serialize(obj):
 
 
 
-
-
-#####
-## RULESTATE VALIDATION
-#####
-
-
-
-
-
-def checksumTSV(folder):
-
-	sums = ""
-
-	for f in os.listdir(folder + "/"):
-		if (f.endswith(".tsv")):
-			f = open(folder + "/" + f,"rb")
-			sums += hashlib.md5(f.read()).hexdigest() + "\n"
-			f.close()
-
-	return sums
-
-# returns whether checksums match and sets the checksum to invalid if they don't (or sets the new one if no previous one exists)
-def combineChecksums(filename,checksums):
-	import os
-
-	if os.path.exists(filename + ".rulestate"):
-		f = open(filename + ".rulestate","r")
-		oldchecksums = f.read()
-		f.close()
-		if oldchecksums == checksums:
-		# the new checksum given by the calling db server represents the rule state that all current unsaved scrobbles were created under
-		# if this is the same as the existing one, we're all good
-			return True
-		elif (oldchecksums != "INVALID"):
-			#if not, the file is not consistent to any single rule state (some scrobbles were created with an old ruleset, some not)
-			f = open(filename + ".rulestate","w")
-			f.write("INVALID") # this will never match any sha256sum
-			f.close()
-			return False
-		else:
-			#if the file already says invalid, no need to open it and rewrite
-			return False
-	else:
-		f = open(filename + ".rulestate","w")
-		f.write(checksums)
-		f.close()
-		return True
-
-# checks ALL files for their rule state. if they are all the same as the current loaded one, the entire database can be assumed to be consistent with the current ruleset
-# in any other case, get out
-def consistentRulestate(folder,checksums):
-
-	result = []
-	for scrobblefile in os.listdir(folder + "/"):
-
-		if (scrobblefile.endswith(".tsv")):
-
-			try:
-				with open(folder + "/" + scrobblefile + ".rulestate","r") as f:
-					if f.read() != checksums:
-						return False
-			except:
-				return False
-
-	return True
-
-
-
-
-
-
-
-
-
-
-
-
-
 #####
 ## IMAGES
 #####
